==> qupzilla_1.6.6.orig.tar.xz: qupzilla-1.6.6.orig/src/plugins/StatusBarIcons/translations/el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="36"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Τροποποίηση ρυθμίσεων φόρτωσης εικόνων ανά σελίδα και γενικά</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="60"/>
        <source>Current page settings</source>
        <translation>Τρέχουσες ρυθμίσεις σελίδας</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="63"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Απενεργοποίηση φόρτωσης εικόνων (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Ενεργοποίηση φόρτωσης εικόνων (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="70"/>
        <source>Global settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="72"/>
        <source>Automatically load images</source>
        <translation>Αυτόματη φόρτωση εικόνων</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="34"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Τροποποίηση ρυθμίσεων JavaScript ανά σελίδα και γενικά</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="49"/>
        <source>Current page settings</source>
        <translation>Τρέχουσες ρυθμίσεις σελίδας</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="52"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Απενεργοποίηση JavaScript (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="55"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Ενεργοποίηση JavaScript (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="59"/>
        <source>Global settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="60"/>
        <source>Manage JavaScript settings</source>
        <translation>Διαχείριση ρυθμίσεων JavaScript</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Proxy configuration</source>
        <translation>Ρύθμιση proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="70"/>
        <source>Select proxy</source>
        <translation>Επιλογή proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Empty</source>
        <translation>Άδειο</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="88"/>
        <source>Manage proxies</source>
        <translation>Διαχείριση των proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="101"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Εμφανίζει την κατάσταση του δικτύου και διαχειρίζεται το proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Δίκτυο:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="104"/>
        <source>Connected</source>
        <translation>Έγινε σύνδεση</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="107"/>
        <source>Offline</source>
        <translation>Εκτός σύνδεσης</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>System proxy</source>
        <translation>Proxy συστήματος</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>No proxy</source>
        <translation>Κανένα proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="120"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>PAC (Proxy Auto-Config)</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="124"/>
        <source>User defined</source>
        <translation>Καθορισμένο από το Χρήστη</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Διαχειριστής proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Επιλογή proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>Προσθήκη proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Αφαίρεση proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Δεν υπάρχουν proxy. Μπορείτε να προσθέσετε proxy κάνοντας κλικ στο κουμπί &lt;b&gt;Προσθήκη&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Όλες  οι αλλαγές πρέπει να αποθηκευτούν με το κουμπί &lt;b&gt;Αποθήκευση&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>Ονομασία του proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>Αφαίρεση του τρέχων proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>Είστε σίγουρος για την αφαίρεση του τρέχων proxy;</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>Να μην χρησιμοποιείται proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>Χρήση διαφορετικού proxy για σύνδεση https</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;Εξαιρέσεις&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>Να μην χρησιμοποιείται σε:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>Θύρα:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>Όνομα χρήστη:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>Κωδικός:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>Χρήση δέσμης ενεργειών για αυτόματη ρύθμιση παραμέτρων:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>Ρύθμιση proxy συστήματος</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>Αρχείο Proxy Auto-Config (.pac)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>Χειροκίνητη ρύθμιση</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>Διακομιστής:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Εικονίδια μπάρας κατάστασης</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Εικονίδια μπάρας κατάστασης&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Αυτά τα εικονίδια θα εμφανίζονται στην μπάρα κατάστασης:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Εικονίδιο εικόνων</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Εικονίδιο JavaScript</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Εικονίδιο δικτύου</translation>
    </message>
</context>
</TS>

==> qupzilla_1.8.6~dfsg1.orig.tar.xz: qupzilla-1.8.6~dfsg1/src/plugins/StatusBarIcons/translations/el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Τροποποίηση ρυθμίσεων φόρτωσης εικόνων ανά σελίδα και γενικά</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>Τρέχουσες ρυθμίσεις σελίδας</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Απενεργοποίηση φόρτωσης εικόνων (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Ενεργοποίηση φόρτωσης εικόνων (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>Αυτόματη φόρτωση εικόνων</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Τροποποίηση ρυθμίσεων JavaScript ανά σελίδα και γενικά</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>Τρέχουσες ρυθμίσεις σελίδας</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>Απενεργοποίηση JavaScript (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>Ενεργοποίηση JavaScript (προσωρινά)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>Διαχείριση ρυθμίσεων JavaScript</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Proxy Configuration</source>
        <translation>Ρυθμίσεις proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="68"/>
        <source>Select proxy</source>
        <translation>Επιλογή proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="82"/>
        <source>Empty</source>
        <translation>Άδειο</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="86"/>
        <source>Manage proxies</source>
        <translation>Διαχείριση των proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="99"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Εμφανίζει την κατάσταση του δικτύου και διαχειρίζεται το proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Δίκτυο:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="102"/>
        <source>Connected</source>
        <translation>Έγινε σύνδεση</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="105"/>
        <source>Offline</source>
        <translation>Εκτός σύνδεσης</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="110"/>
        <source>System proxy</source>
        <translation>Proxy συστήματος</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="114"/>
        <source>No proxy</source>
        <translation>Κανένα proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="118"/>
        <source>PAC (Proxy Auto-Config)</source>
        <translation>PAC (Proxy Auto-Config)</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="122"/>
        <source>User defined</source>
        <translation>Καθορισμένο από το Χρήστη</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Διαχειριστής proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Επιλογή proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Add proxy</source>
        <translation>Προσθήκη proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Αφαίρεση proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Δεν υπάρχουν proxy. Μπορείτε να προσθέσετε proxy κάνοντας κλικ στο κουμπί &lt;b&gt;Προσθήκη&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Όλες  οι αλλαγές πρέπει να αποθηκευτούν με το κουμπί &lt;b&gt;Αποθήκευση&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="55"/>
        <source>Name of proxy:</source>
        <translation>Ονομασία του proxy:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Remove current proxy</source>
        <translation>Αφαίρεση του τρέχων proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="68"/>
        <source>Are you sure to remove current proxy?</source>
        <translation>Είστε σίγουρος για την αφαίρεση του τρέχων proxy;</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="20"/>
        <source>Do not use proxy</source>
        <translation>Να μην χρησιμοποιείται proxy</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="27"/>
        <source>Use different proxy for https connection</source>
        <translation>Χρήση διαφορετικού proxy για σύνδεση https</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="34"/>
        <source>&lt;b&gt;Exceptions&lt;/b&gt;</source>
        <translation>&lt;b&gt;Εξαιρέσεις&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="43"/>
        <source>Don&apos;t use on:</source>
        <translation>Να μην χρησιμοποιείται σε:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="58"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="63"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="74"/>
        <location filename="../sbi_proxywidget.ui" line="220"/>
        <source>Port:</source>
        <translation>Θύρα:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <location filename="../sbi_proxywidget.ui" line="243"/>
        <source>Username:</source>
        <translation>Όνομα χρήστη:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="121"/>
        <location filename="../sbi_proxywidget.ui" line="253"/>
        <source>Password:</source>
        <translation>Κωδικός:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="146"/>
        <source>Use script for automatic configuration:</source>
        <translation>Χρήση δέσμης ενεργειών για αυτόματη ρύθμιση παραμέτρων:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="153"/>
        <source>System proxy configuration</source>
        <translation>Ρύθμιση proxy συστήματος</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="162"/>
        <source>Proxy Auto-Config (.pac) file</source>
        <translation>Αρχείο Proxy Auto-Config (.pac)</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="187"/>
        <source>Manual configuration</source>
        <translation>Χειροκίνητη ρύθμιση</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="210"/>
        <source>Server:</source>
        <translation>Διακομιστής:</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Εικονίδια μπάρας κατάστασης</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Εικονίδια μπάρας κατάστασης&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Αυτά τα εικονίδια θα εμφανίζονται στην μπάρα κατάστασης:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Εικονίδιο εικόνων</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>Εικονίδιο JavaScript</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Εικονίδιο δικτύου</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Γραφικό στοιχείο εστίασης</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>Εστίαση: %1%</translation>
    </message>
</context>
</TS>
